@@ -1,6 +1,6 @@
 use strict;
 use warnings;
-use 5.022;
+use 5.024;
 
 use feature qw /postderef signatures/;
 
@@ -9,15 +9,14 @@ use Moose::Role;
 
 no warnings 'experimental';
 use Path::Tiny 0.108;
-# use Data::Printer;
 
-our $VERSION='1.05';
+our $VERSION='1.20';
 
 =head1 NAME
 
 Vote::Count::Log
 
-=head1 VERSION 1.05
+=head1 VERSION 1.20
 
 =cut
 
@@ -37,19 +36,27 @@ The default log location is '/tmp/votecount'.
 
 =head2 LogPath
 
-Specifies a Path to the Log Files, unlike LogTo, LogPath will create the Path if it does not exist. 
+Specifies a Path to the Log Files, unlike LogTo, LogPath will create the Path if it does not exist.
 
-=head2 LogBaseName 
+=head2 LogBaseName
 
 Sets the Base portion of the logfile names, but only if LogPath is specified. The default value is votecount.
 
-=head2 WriteLogs
+=head2 WriteLog
 
 Write the logs appending '.brief', '.full', and '.debug' for the three logs where brief is a summary written with the logt (log terse) method, the full transcript log written with logv, and finally the debug log written with logd. Each higher log level captures all events of the lower log levels.
 
 =head1 Logging Events
 
-When logging from your methods, use logt for events that produce a summary, use logv for events that should be in the full transcript such as round counts, and finally debug is for events that may be helpful in debugging but which should not be in the transcript. Events written to logt will be included in the verbose log and all events in the verbose log will be in the debug log. 
+When logging from your methods, use logt for events that produce a summary, use logv for events that should be in the full transcript such as round counts, and finally debug is for events that may be helpful in debugging but which should not be in the transcript. Events written to logt will be included in the verbose log and all events in the verbose log will be in the debug log.
+
+=head1 Debug Flag
+
+When the debug flag is logx methods will also emit the event as a warning (STDERR). The Debug Flag defaults to off (0), but can be explicitly set via the new method of a Vote::Count object, or toggled by passing 0 or 1 via the Debug Method.
+
+  $Election->Debug(1); # turn debug on
+  is( $Election->Action(), $expected, 'Thing Im debugging');
+  $Election->Debug(0); # turn debug off
 
 =cut
 
@@ -72,6 +79,12 @@ has 'LogBaseName' => (
   default => 'votecount'
 );
 
+has 'Debug' => (
+  default => 0,
+  is => 'rw',
+  isa => 'Bool',
+  );
+
 sub _logsetup ( $self ) {
   my $pathBase = $self->{'LogPath'} || '/tmp';
   $pathBase =~ s/\/$|\\$//;    # trim \ or / from end.
@@ -108,6 +121,7 @@ sub logd {
   # unshift @args, localtime->date . ' ' . localtime->time;
   my $msg = join( "\n", @args ) . "\n";
   $self->{'LogD'} .= $msg;
+  warn $msg if $self->Debug();
 }
 
 sub WriteLog {
