@@ -1,38 +1,40 @@
 use strict;
 use warnings;
-use 5.022;
+use 5.024;
 use feature qw /postderef signatures/;
 
 package Vote::Count::Matrix;
 use Moose;
 
-with 'Vote::Count::TieBreaker',
+with
+  'Vote::Count::Common',
   'Vote::Count::Approval',
   'Vote::Count::Borda',
   'Vote::Count::Log',
   'Vote::Count::Score',
+  'Vote::Count::TieBreaker',
   ;
 
 use Vote::Count::RankCount;
 
 no warnings 'experimental';
 use List::Util qw( min max sum );
-use Vote::Count::TextTableTiny qw/generate_markdown_table/;
+use Vote::Count::TextTableTiny qw/generate_table/;
 use Sort::Hash;
+use Storable 3.15 'dclone';
 
 # use Try::Tiny;
-#use Data::Printer;
 #use Data::Dumper;
 
 use YAML::XS;
 
-our $VERSION='1.05';
+our $VERSION='1.20';
 
 =head1 NAME
 
 Vote::Count::Matrix
 
-=head1 VERSION 1.05
+=head1 VERSION 1.20
 
 =cut
 
@@ -44,13 +46,6 @@ has BallotSet => (
   isa      => 'HashRef',
 );
 
-has Active => (
-  is      => 'rw',
-  isa     => 'HashRef',
-  builder => 'Vote::Count::Matrix::_buildActive',
-  lazy    => 1,
-);
-
 has TieBreakMethod => (
   is       => 'rw',
   isa      => 'Str',
@@ -58,10 +53,6 @@ has TieBreakMethod => (
   default  => 'none',
 );
 
-sub _buildActive ( $self ) {
-  return $self->BallotSet->{'choices'};
-}
-
 sub _untie ( $I, $A, $B ) {
   my @untie = $I->TieBreaker( $I->TieBreakMethod(), $I->Active(), $A, $B );
   return $untie[0] if ( scalar(@untie) == 1 );
@@ -75,11 +66,11 @@ FORVOTES:
   for my $b ( keys $ballots->%* ) {
     for my $v ( values $ballots->{$b}{'votes'}->@* ) {
       if ( $v eq $A ) {
-        $countA += $ballots->{$b}{'count'};
+        $countA += $ballots->{$b}{'count'} * $ballots->{$b}{'votevalue'};
         next FORVOTES;
       }
       elsif ( $v eq $B ) {
-        $countB += $ballots->{$b}{'count'};
+        $countB += $ballots->{$b}{'count'}  * $ballots->{$b}{'votevalue'};
         next FORVOTES;
       }
     }
@@ -249,7 +240,8 @@ sub CondorcetWinner( $self ) {
 sub GreatestLoss ( $self, $A ) {
   my $bigloss = 0;
 GREATESTLOSSLOOP:
-  for my $B ( keys $self->Active()->%* ) {
+  for my $B ( $self->GetActiveList() ) {
+  # for my $B ( keys $self->Active()->%* ) {
     next GREATESTLOSSLOOP if $B eq $A;
     my %result = $self->{'Matrix'}{$A}{$B}->%*;
 # warn "$A : $B loser $result{'loser'} : margin $result{'margin'} $A: $result{$A} $B: $result{$B}";
@@ -271,7 +263,7 @@ sub RankGreatestLoss ( $self, $active = undef ) {
 
 # reset active to choices
 sub ResetActive ( $self ) {
-  $self->{'Active'} = $self->BallotSet->{'choices'};
+  $self->{'Active'} = dclone $self->BallotSet->{'choices'};
 }
 
 sub _getsmithguessforchoice ( $h, $matrix ) {
@@ -338,7 +330,7 @@ sub ScoreTable ( $self ) {
     # for my $c ( sort ( keys $scores->%* ) ) {
     push @rows, [ $c, $scores->{$c} ];
   }
-  return generate_markdown_table( rows => \@rows );
+  return generate_table( rows => \@rows );
 }
 
 sub MatrixTable ( $self, $options = {} ) {
@@ -373,7 +365,7 @@ sub MatrixTable ( $self, $options = {} ) {
     push @newrow, $topcount if $o_topcount;
     push @rows, \@newrow;
   }
-  return generate_markdown_table( rows => \@rows );
+  return generate_table( rows => \@rows );
 }
 
 sub PairingVotesTable ( $self ) {
@@ -396,7 +388,7 @@ sub PairingVotesTable ( $self ) {
       push @rows, [ ' ', $Cstr, $CVote, $Ostr, $OVote ];
     }
   }
-  return generate_markdown_table( rows => \@rows );
+  return generate_table( rows => \@rows );
 }
 
 1;
