@@ -1,6 +1,6 @@
 package Vote::Count::ReadBallots;
 
-use 5.022;
+use 5.024;
 use feature qw/postderef signatures/;
 no warnings qw/experimental/;
 use Path::Tiny 0.108;
@@ -8,21 +8,20 @@ use Carp;
 use JSON::MaybeXS;
 use YAML::XS;
 # use Data::Dumper;
-use Data::Printer;
 
 # ABSTRACT: Read Ballots for Vote::Count. Toolkit for vote counting.
 
-our $VERSION='1.05';
+our $VERSION='1.20';
 
 =head1 NAME
 
 Vote::Count::ReadBallots
 
-=head1 VERSION 1.05
+=head1 VERSION 1.20
 
 =head1 SYNOPSIS
 
-  Vote::Count::ReadBallots;
+  use Vote::Count::ReadBallots;
 
   my $data1 = read_ballots('t/data/data1.txt');
 
@@ -37,6 +36,7 @@ All public methods are exported.
     ballots   {
         CHOCOLATE:MINTCHIP:VANILLA {
             count   1,
+            votevalue   1, # needed for STV support
             votes   [
                 [0] "CHOCOLATE",
                 [1] "MINTCHIP",
@@ -140,12 +140,11 @@ sub read_ballots( $filename ) {
     'comment'   => ''
   );
 BALLOTREADLINES:
-  for my $line_raw ( path($filename)->lines ) {
+  for my $line_raw ( path($filename)->lines({chomp => 1}) ) {
     if ( $line_raw =~ m/^\#/ ) {
       $data{'comment'} .= $line_raw;
       next BALLOTREADLINES;
     }
-    chomp $line_raw;
     if ( $line_raw =~ m/^\:CHOICES\:/ ) {
       if ( $data{'choices'} ) {
         croak("File $filename redefines CHOICES \n$line_raw\n");
@@ -176,6 +175,7 @@ BALLOTREADLINES:
       $data{'ballots'}{$line}{'votes'} = \@votes;
     }
   }
+  for my  $K ( keys $data{'ballots'}->%* ) { $data{'ballots'}{$K}{'votevalue'} = 1 }
   return \%data;
 }
 
@@ -187,7 +187,7 @@ sub write_ballots ( $BallotSet, $destination ) {
     my $cnt = $BallotSet->{'ballots'}{$k}{'count'};
     push @data, "$cnt:$k";
   }
-  for (@data) { $_ .= "\n" if $_ !~ /\n$/ }
+  for my $D (@data) { $D .= "\n" if $D !~ /\n$/ }
   path($destination)->spew(@data);
 }
 
